@@ -51,6 +51,11 @@ class FastAPIAdapter:
         self.app_dir = Path(app_dir)
         self.config = config or Config
         self.router = Router(self.app_dir, config=self.config)
+
+        # Apply OpenAPI configuration
+        self._setup_openapi_paths()
+
+        # Setup CORS
         self._setup_cors()
 
     def register_routes(self) -> None:
@@ -300,6 +305,45 @@ class FastAPIAdapter:
         if self.config.VERBOSE_LOGGING:
             print(f"  {method:7} {full_path}")
 
+    def _setup_openapi_paths(self) -> None:
+        """
+        Apply custom OpenAPI documentation paths from configuration.
+
+        Respects None values for individual endpoints:
+        - DOCS_PATH = None -> disables Swagger UI
+        - REDOC_PATH = None -> disables ReDoc UI
+        - JSON_PATH = None -> disables OpenAPI JSON endpoint
+        """
+        if hasattr(self.config, 'OpenAPI'):
+            # Set docs URLs based on config
+            if self.config.OpenAPI.ENABLE:
+                # Respect None values for individual endpoints
+                self.app.docs_url = self.config.OpenAPI.DOCS_PATH if self.config.OpenAPI.DOCS_PATH else None
+                self.app.redoc_url = self.config.OpenAPI.REDOC_PATH if self.config.OpenAPI.REDOC_PATH else None
+                self.app.openapi_url = self.config.OpenAPI.JSON_PATH if self.config.OpenAPI.JSON_PATH else None
+            else:
+                # Disable all docs if OpenAPI is disabled
+                self.app.docs_url = None
+                self.app.redoc_url = None
+                self.app.openapi_url = None
+
+            # Remove routes for disabled endpoints
+            # FastAPI may have already registered routes with default URLs
+            routes_to_remove = []
+            for route in self.app.routes:
+                if hasattr(route, 'path'):
+                    # Check if this is a docs route that should be disabled
+                    if self.app.docs_url is None and route.path in ['/docs', '/docs/oauth2-redirect']:
+                        routes_to_remove.append(route)
+                    elif self.app.redoc_url is None and route.path == '/redoc':
+                        routes_to_remove.append(route)
+                    elif self.app.openapi_url is None and route.path == '/openapi.json':
+                        routes_to_remove.append(route)
+
+            # Remove disabled routes
+            for route in routes_to_remove:
+                self.app.routes.remove(route)
+
     def _setup_cors(self) -> None:
         """
         Setup CORS middleware globally based on configuration.
@@ -365,3 +409,147 @@ class FastAPIAdapter:
         """
         for method in methods:
             self._register_fastapi_route(path, method.upper(), handler, None)
+
+    def run_server(self, project_name: Optional[str] = None, **uvicorn_kwargs) -> None:
+        """
+        Run the FastAPI application server with uvicorn.
+
+        This is a convenience method that:
+        - Checks port availability
+        - Shows formatted startup messages
+        - Passes configuration to uvicorn
+        - Allows overriding config values via kwargs
+
+        Args:
+            project_name: Optional project name for display
+            **uvicorn_kwargs: Additional uvicorn parameters (override config values)
+                Common parameters:
+                - host (str): Host to bind (default: from config.HOST)
+                - port (int): Port to bind (default: from config.PORT)
+                - reload (bool): Enable auto-reload (default: from config.AUTO_RELOAD)
+                - workers (int): Number of worker processes
+                - log_level (str): Logging level ("critical", "error", "warning", "info", "debug", "trace")
+                - access_log (bool): Enable access log
+                - use_colors (bool): Enable colored logging
+                - proxy_headers (bool): Enable X-Forwarded-Proto, X-Forwarded-For headers
+                - forwarded_allow_ips (str): Comma-separated list of IPs to trust with proxy headers
+
+        Examples:
+            # Basic usage
+            adapter.run_server()
+
+            # Override port
+            adapter.run_server(port=8080)
+
+            # Custom log level and workers
+            adapter.run_server(workers=4, log_level="debug")
+
+            # Disable reload even if config has AUTO_RELOAD=True
+            adapter.run_server(reload=False)
+        """
+        try:
+            import uvicorn
+        except ImportError:
+            raise ImportError(
+                "uvicorn is not installed. Install it with: pip install reroute[fastapi]"
+            )
+
+        from reroute.utils import ensure_port_available
+
+        # Get configuration defaults (can be overridden by uvicorn_kwargs)
+        HOST = getattr(self.config, 'HOST', '0.0.0.0')
+        PORT = getattr(self.config, 'PORT', 8000)
+        RELOAD = getattr(self.config, 'AUTO_RELOAD', False)
+
+        # Merge uvicorn arguments (kwargs override config)
+        uvicorn_config = {
+            "host": HOST,
+            "port": PORT,
+            "reload": RELOAD,
+            **uvicorn_kwargs  # User kwargs take precedence
+        }
+
+        # Get final values after merge
+        final_host = uvicorn_config.get("host", HOST)
+        final_port = uvicorn_config.get("port", PORT)
+        final_reload = uvicorn_config.get("reload", RELOAD)
+
+        # Check port availability
+        ensure_port_available(final_host, final_port)
+
+        # Display startup banner (auto-detect from FastAPI app title if not provided)
+        if not project_name:
+            project_name = getattr(self.app, 'title', None) or "REROUTE Application"
+
+        print("\n" + "="*50)
+        print(f"{project_name} - REROUTE + FastAPI")
+        print("="*50)
+        print("\nStarting server...")
+
+        # Show docs URLs if OpenAPI is enabled and paths are configured
+        if hasattr(self.config, 'OpenAPI') and self.config.OpenAPI.ENABLE:
+            docs_shown = False
+            if self.config.OpenAPI.DOCS_PATH:
+                print(f"API Docs (Swagger): http://localhost:{final_port}{self.config.OpenAPI.DOCS_PATH}")
+                docs_shown = True
+            if self.config.OpenAPI.REDOC_PATH:
+                print(f"API Docs (ReDoc):   http://localhost:{final_port}{self.config.OpenAPI.REDOC_PATH}")
+                docs_shown = True
+            if self.config.OpenAPI.JSON_PATH:
+                print(f"OpenAPI Spec:       http://localhost:{final_port}{self.config.OpenAPI.JSON_PATH}")
+                docs_shown = True
+            if not docs_shown:
+                print("API Docs: Disabled (all paths set to None)")
+
+        print(f"Health Check: http://localhost:{final_port}/health")
+        print("\n")
+
+        # When reload is enabled, uvicorn requires an import string instead of app object
+        # Try to detect the import path, otherwise disable reload with a warning
+        if final_reload:
+            import inspect
+            import sys
+
+            # Try to find the module where run_server was called from
+            frame = inspect.currentframe()
+            caller_frame = frame.f_back  # Get caller's frame
+            caller_module = inspect.getmodule(caller_frame)
+
+            if caller_module and hasattr(caller_module, '__file__') and caller_module.__file__:
+                # Extract module name from file path
+                import os
+                module_file = os.path.abspath(caller_module.__file__)
+                module_name = os.path.basename(module_file).replace('.py', '')
+
+                # Find the app variable name in the caller's local scope
+                app_var_name = None
+                for var_name, var_value in caller_frame.f_locals.items():
+                    if var_value is self:
+                        # Found the adapter variable, now find app
+                        if hasattr(var_value, 'app') and var_value.app is self.app:
+                            # Look for the app variable
+                            for app_var, app_val in caller_frame.f_globals.items():
+                                if app_val is self.app:
+                                    app_var_name = app_var
+                                    break
+                            break
+
+                # Default to 'app' if we can't find the variable name
+                if not app_var_name:
+                    app_var_name = 'app'
+
+                # Construct import string (e.g., "main:app")
+                app_import_string = f"{module_name}:{app_var_name}"
+
+                print(f"[INFO] Auto-reload enabled: {app_import_string}\n")
+
+                # Start server with import string
+                uvicorn.run(app_import_string, **uvicorn_config)
+            else:
+                # Can't determine import path, disable reload
+                print("[WARNING] Could not determine import path for reload. Disabling auto-reload.\n")
+                uvicorn_config["reload"] = False
+                uvicorn.run(self.app, **uvicorn_config)
+        else:
+            # Start server normally without reload
+            uvicorn.run(self.app, **uvicorn_config)
